@@ -10,7 +10,7 @@ use File::Basename;
 use Carp;
 use MIME::Base64;
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 sub _get_boundary {
     my ($headers, $content) = @_;
@@ -107,7 +107,7 @@ no warnings 'redefine';
     my $boundary      = _get_boundary($headers, $content_parts);
 
     my $last_boundary = $boundary;
-    substr $last_boundary, -3, 0, "--";
+    substr $last_boundary, -2, 0, "--";
  
     return $self->request('POST', $url, {
             %$args,
@@ -133,7 +133,7 @@ HTTP::Tiny::Multipart - Add post_multipart to HTTP::Tiny
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -179,7 +179,8 @@ And
             filename => 'test.txt',
             content  => $content,
             content_type  => 'text/plain',
-        }
+        },
+        testfield => 'test'
     } );
 
 creates
@@ -196,19 +197,27 @@ creates
   Content-Type: text/plain
   
   This is a test
-  --go7DX--
+  --go7DX
   Content-Disposition: form-data; name="testfield"
   
   test
   --go7DX--
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item * Stephen Thirlwall
+
+=back
+
 =head1 AUTHOR
 
 Renee Baecker <reneeb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Renee Baecker.
+This software is Copyright (c) 2015 by Renee Baecker.
 
 This is free software, licensed under:
 
